PublishPlanEntry class

What a publish run will do with one repository of a ticket.

Constructors

PublishPlanEntry({required String name, required Directory directory, required bool publishes, required String reason, required bool alreadyPublished, String? versionIncrement, String? mergeMessage, String? pullRequestBody})
Constructor
const

Properties

alreadyPublished bool
Whether an earlier run of the same publish already released it.
final
directory Directory
The repository's folder.
final
hashCode int
The hash code for this object.
no setterinherited
mergeMessage String?
The merge message it will be published with, or null when unknown. gg do review uses it as the title of the repository's pull request.
final
name String
The repository's folder name — the key of its .gg-publish.json entry.
final
publishes bool
Whether the repository needs a release.
final
pullRequestBody String?
The description of the repository's pull request — the commits recorded in its publish_config.json, or null when it recorded none.
final
reason String
Why it needs one — or why it does not.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
versionIncrement String?
The increment it will be published with, or null when unknown.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited