helixSelectPrompt function

Future<int> helixSelectPrompt({
  1. required String prompt,
  2. required List<String> options,
})

Answers the questions of helix through the prompts of the gg suite — the same menus gg do publish draws, and in an embedded gg whatever the embedder assigned to GgPrompts.current.

Implementation

Future<int> helixSelectPrompt({
  required String prompt,
  required List<String> options,
}) => GgPrompts.current.select(prompt: prompt, options: options);